@@ -3,7 +3,7 @@ import os
 from typing import Dict, List, Tuple
 
 from misty2py.robot import Misty
-from misty2py.utils.messages import success_parser_from_dicts
+from misty2py.response import success_of_action_dict
 from misty2py.utils.utils import get_abs_path
 
 
@@ -23,7 +23,8 @@ def get_non_system_assets(
     action = "_list"
     non_sys_assets = {}
     for asset in assets:
-        data = misty.get_info(asset + action)
+        data = misty.get_info(asset + action).parse_to_dict()
+        data = data.get("rest_response", {})
         result = data.get("result", [])
         for hit in result:
             name = hit.get("name")
@@ -36,8 +37,7 @@ def get_non_system_assets(
                     non_sys_assets[asset] = []
                 non_sys_assets[asset].append(name)
                 print(
-                    "Found a non-system asset \
-                        of type `%s` named `%s`." % (asset, name)
+                    "Found a non-system asset of type `%s` named `%s`." % (asset, name)
                 )
 
     return non_sys_assets
@@ -68,17 +68,13 @@ def get_asset_properties(asset_type: str, file: str) -> Tuple[Dict, str, str]:
     return params, name, ext
 
 
-def save_base64_str(
-    full_path: str,
-    content: str,
-    overwrite: bool = False
-) -> bool:
+def save_base64_str(full_path: str, content: str, overwrite: bool) -> bool:
     """Saves an asset content to the file specified by `full_path`.
 
     Args:
         full_path (str): The absolute path to the save location.
         content (str): The base64 content to save.
-        overwrite (bool, optional): Whether the overwrite the file if it exists. Defaults to `False`.
+        overwrite (bool): Whether the overwrite the file if it exists.
 
     Returns:
         bool: The successfulness of the operation.
@@ -94,21 +90,22 @@ def save_base64_str(
         return True
 
     except Exception as e:
-        print("Failed to save the asset into `%s`. Error message: `%s`" % (
-            full_path,
-            e
-            )
+        print(
+            "Failed to save the asset into `%s`. Error message: `%s`" % (full_path, e)
         )
         return False
 
 
-def save_assets(misty: Misty, assets: Dict, location: str) -> List[str]:
+def save_assets(
+    misty: Misty, assets: Dict, location: str, overwrite: bool
+) -> List[str]:
     """Saves multiple assets.
 
     Args:
         misty (Misty): the Misty whose assets to save.
         assets (Dict): The dictionary of assets; a list of file names under their asset type as the keyword.
         location (str): The absolute path to the directory where the assets are saved.
+        overwrite (bool): Whether the overwrite the file if it exists.
 
     Returns:
         List[str]: A list of file names for the files that failed to be saved.
@@ -118,7 +115,10 @@ def save_assets(misty: Misty, assets: Dict, location: str) -> List[str]:
     for asset_type, files in assets.items():
         for file in files:
             params, name, ext = get_asset_properties(asset_type, file)
-            response = misty.get_info(asset_type + action, params=params)
+            response = misty.get_info(
+                asset_type + action, params=params
+            ).parse_to_dict()
+            response = response.get("rest_response", {})
             result = response.get("result")
 
             if not result:
@@ -131,18 +131,14 @@ def save_assets(misty: Misty, assets: Dict, location: str) -> List[str]:
                 if not file_content:
                     failed_list.append(file)
                 else:
-                    success = save_base64_str(full_path, file_content)
+                    success = save_base64_str(full_path, file_content, overwrite)
                     if not success:
                         failed_list.append(file)
 
     return failed_list
 
 
-def delete_assets(
-    misty: Misty,
-    assets: Dict,
-    ignore_list: List = []
-) -> List[str]:
+def delete_assets(misty: Misty, assets: Dict, ignore_list: List = []) -> List[str]:
     """Deletes all non-system files except those that are in `ignore_list`.
 
     Args:
@@ -163,17 +159,19 @@ def delete_assets(
                     data = {"Name": file}
                 else:
                     data = {"FileName": file}
-                response = misty.perform_action(asset_type + action, data=data)
-                status = response.get("status")
+                response = misty.perform_action(
+                    asset_type + action, data=data
+                ).parse_to_dict()
+                response = response.get("rest_response", {})
+                status = response.get("success")
                 if status:
-                    if status == "Success":
-                        print("Successfully deleted the asset `%s`." % file)
-                        delete_list.append(file)
-                    else:
-                        print(
-                            "Failed to delete the asset `%s`. Message: `%s`"
-                            % (file, response)
-                        )
+                    print("Successfully deleted the asset `%s`." % file)
+                    delete_list.append(file)
+                else:
+                    print(
+                        "Failed to delete the asset `%s`. Message: `%s`"
+                        % (file, response)
+                    )
 
     return delete_list
 
@@ -182,6 +180,7 @@ def free_memory(
     misty: Misty,
     assets: List = ["audio", "image", "video", "recording"],
     save: bool = True,
+    overwrite: bool = False,
     save_dir: str = "data",
 ) -> Dict:
     """Removes all non-system files in Misty's memory.
@@ -190,21 +189,22 @@ def free_memory(
         misty (Misty): the Misty whose memory to free.
         assets (List, optional): The list of asset types to delete. Defaults to `["audio", "image", "video", "recording"]`.
         save (bool, optional): Whether to save the files that are being deleted from Misty's memory. Defaults to `True`.
+        overwrite (bool): Whether the overwrite the file if it exists. Defaults to `False`.
         save_dir (str, optional): The path to the directory that will store saved assets. Defaults to `"data"`.
 
     Returns:
-        Dict: The dictionary with keys `overall_success` for the success of the entire operation and keys corresponding to the actions within the operation with successfulness of the action and messages about the action.
+        Dict: a dictionary with the key `overall_success` specifying whether all actions were successful and a key for every action containing the dictionarised Misty2pyResponse to that action.
     """
     save_dir = get_abs_path(save_dir)
-    enable_audio = misty.perform_action("audio_enable")
-    enable_av = misty.perform_action("streaming_av_enable")
-    enable_camera = misty.perform_action("camera_enable")
+    enable_audio = misty.perform_action("audio_enable").parse_to_dict()
+    enable_av = misty.perform_action("streaming_av_enable").parse_to_dict()
+    enable_camera = misty.perform_action("camera_enable").parse_to_dict()
 
     assets_to_delete = get_non_system_assets(misty, assets=assets)
     deletion = {}
 
     if len(assets_to_delete) == 0:
-        deletion["status"] = "Success"
+        deletion["success"] = True
         deletion["message"] = "No non-system files present."
 
     else:
@@ -212,31 +212,33 @@ def free_memory(
 
         if save:
             failed_to_save_list = save_assets(
-                misty,
-                assets_to_delete,
-                save_dir
+                misty, assets_to_delete, save_dir, overwrite
             )
 
         deleted = delete_assets(misty, assets_to_delete, failed_to_save_list)
 
         if len(deleted) > 0:
-            deletion["status"] = "Success"
-            deletion["message"] = "Successfully deleted \
-                following assets: %s" % str(deleted)
+            deletion["success"] = True
+            deletion["message"] = "Successfully deleted following assets: %s" % str(
+                deleted
+            )
 
         else:
-            deletion["status"] = "Failed"
+            deletion["success"] = False
             deletion["message"] = "Failed to delete any assets."
 
-    disable_audio = misty.perform_action("audio_disable")
-    disable_av = misty.perform_action("streaming_av_disable")
-    disable_camera = misty.perform_action("camera_disable")
+    disable_audio = misty.perform_action("audio_disable").parse_to_dict()
+    disable_av = misty.perform_action("streaming_av_disable").parse_to_dict()
+    disable_camera = misty.perform_action("camera_disable").parse_to_dict()
 
-    return success_parser_from_dicts(
+    return success_of_action_dict(
         enable_audio=enable_audio,
         enable_av=enable_av,
         enable_camera=enable_camera,
-        deletion=deletion,
+        deletion={
+            "overall_success": deletion["success"],
+            "misty2py_response": deletion,
+        },
         disable_audio=disable_audio,
         disable_av=disable_av,
         disable_camera=disable_camera,
