@@ -5,7 +5,7 @@ from misty2py.robot import Misty
 
 
 class Movement:
-    """Handles Misty's movement."""
+    """Handles Misty's movement. All angles are in degrees as integers."""
 
     def __init__(
         self,
@@ -48,7 +48,7 @@ class Movement:
             value (int): the input value.
             max (int): the maximal allowed value.
             min (int): the minimal allowed value.
-            negative (bool, optional): Whether the input value should be transformed into its negative. Defaults to `False`.
+            negative (bool, optional): Whether the output value should be its negative (if the input is positive) or remain negative/stagnant if the input is not positive. Defaults to `False`.
             negatives_allowed (bool, optional): Whether an input value can be negative. Defaults to `False`.
 
         Returns:
@@ -71,7 +71,7 @@ class Movement:
             if value > max * (-1):
                 # velocity below min, over negative max
                 return value
-            # velocity over negative max
+            # velocity below negative max
             return max * (-1)
 
         if value < min:
@@ -130,7 +130,7 @@ class Movement:
             "LinearVelocity": self._parse_velocity(velocity),
             "AngularVelocity": self.stagnant_angle,
         }
-        return misty.perform_action("drive", data=forw)
+        return misty.perform_action("drive", data=forw).parse_to_dict()
 
     def drive_backward(self, misty: Misty, velocity: int):
         """Drives backwards with the specified velocity."""
@@ -138,7 +138,7 @@ class Movement:
             "LinearVelocity": self._parse_velocity(velocity, negative=True),
             "AngularVelocity": self.stagnant_angle,
         }
-        return misty.perform_action("drive", data=back)
+        return misty.perform_action("drive", data=back).parse_to_dict()
 
     def drive_left(self, misty: Misty, velocity: int, angle: int):
         """Drives left with the specified velocity and angle."""
@@ -146,7 +146,7 @@ class Movement:
             "LinearVelocity": self._parse_velocity(velocity),
             "AngularVelocity": self._parse_angle(angle),
         }
-        return misty.perform_action("drive", data=left)
+        return misty.perform_action("drive", data=left).parse_to_dict()
 
     def drive_right(self, misty: Misty, velocity: int, angle: int):
         """Drives right with the specified velocity and angle."""
@@ -155,8 +155,8 @@ class Movement:
             "LinearVelocity": self._parse_velocity(velocity),
             "AngularVelocity": self._parse_angle(angle, negative=True),
         }
-        return misty.perform_action("drive", data=right)
+        return misty.perform_action("drive", data=right).parse_to_dict()
 
     def stop_driving(self, misty: Misty):
         """Stops driving."""
-        return misty.perform_action("drive_stop")
+        return misty.perform_action("drive_stop").parse_to_dict()
