@@ -4,7 +4,7 @@ from typing import Dict
 
 from misty2py.robot import Misty
 from misty2py.utils.generators import get_random_string
-from misty2py.utils.messages import compose_json_reply
+from misty2py.response import compose_custom_response
 
 
 def speak(misty: Misty, utterance: str) -> Dict:
@@ -15,16 +15,13 @@ def speak(misty: Misty, utterance: str) -> Dict:
         utterance (str): The utterance to speak.
 
     Returns:
-        Dict: the response, including the `status` keyword and the `message` keyword which contains the utterance spoken.
+        Dict: the enhanced dictionarised Misty2pyResponse.
     """
     result = misty.perform_action(
         "speak",
-        data={
-            "Text": utterance,
-            "UtteranceId": "utterance_" + get_random_string(6)
-            },
-    )
-    return compose_json_reply(
+        data={"Text": utterance, "UtteranceId": "utterance_" + get_random_string(6)},
+    ).parse_to_dict()
+    return compose_custom_response(
         result,
         success_message="Talking successful. Utterance: `%s`." % utterance,
         fail_message="Talking failed. Utterance: `%s`." % utterance,
