@@ -3,10 +3,11 @@
 import json
 from os import path
 from typing import Dict
-from urllib.parse import urlencode
 
 import requests
 
+from misty2py.response import *
+
 this_directory = path.abspath(path.dirname(__file__))
 INFOS_JSON = str(path.join(this_directory, "allowed_infos.json"))
 
@@ -15,19 +16,22 @@ class Get:
     """A class representing the GET url request method.
 
     Attributes:
-        ip (str): The IP address where the requests are sent
+        ip (str): The IP address for the URL where the requests are sent.
+        protocol (str): The protocol for the URL where the requests are sent.
         allowed_infos (dict): The dictionary of information keywords matching to the Misty's API endpoints.
     """
 
-    def __init__(self, ip: str, custom_allowed_infos: Dict = {}) -> None:
+    def __init__(self, ip: str, protocol: str, custom_allowed_infos: Dict = {}) -> None:
         """Initialises a Get object.
 
         Args:
-            ip (str): The IP address where the requests are sent.
+            ip (str): The IP address for the URL where the requests are sent.
+            protocol (str): The protocol for the URL where the requests are sent.
             custom_allowed_infos (Dict, optional): The dictionary of custom information keywords. Defaults to `{}`.
         """
 
         self.ip = ip
+        self.protocol = protocol
 
         allowed_infos = custom_allowed_infos
         f = open(INFOS_JSON)
@@ -36,28 +40,36 @@ class Get:
 
         self.allowed_infos = allowed_infos
 
-    def get_info(self, endpoint: str) -> Dict:
+    def get_info(self, endpoint: str, params: Dict) -> Misty2pyResponse:
         """Sends a GET request.
 
         Args:
             endpoint (str): The API endpoint to which the request is sent.
 
         Returns:
-            Dict: The response from Misty's REST API.
+            Misty2pyResponse: A Misty2pyResponse object with Misty2py sub-response and Misty REST API sub-response.
         """
 
-        r = requests.get("http://%s/%s" % (self.ip, endpoint))
+        r = requests.get(
+            "%s://%s/%s" % (self.protocol, self.ip, endpoint), params=params
+        )
         try:
-            return r.json()
+            return Misty2pyResponse(True, rest_response=r.json())
+
         except Exception as e:
-            return {"status": "Success", "content": r.content, "error_msg": e}
+            return Misty2pyResponse(
+                False,
+                rest_response=r.content,
+                error_msg=e,
+                error_type=Misty2pyErrorType.UNKNOWN,
+            )
 
 
 class Info(Get):
     """A class representing an information request from Misty.
     A subclass of Get()."""
 
-    def get_info(self, info_name: str, params: Dict = {}) -> Dict:
+    def get_info(self, info_name: str, params: Dict = {}) -> Misty2pyResponse:
         """Sends an information request to Misty.
 
         Args:
@@ -65,30 +77,20 @@ class Info(Get):
             params (Dict): dict of parameter name and parameter value. Defaults to `{}`.
 
         Returns:
-            Dict: The response from Misty's REST API.
+            Misty2pyResponse: A Misty2pyResponse object with Misty2py sub-response and Misty REST API sub-response.
         """
 
         if info_name not in self.allowed_infos.keys():
-            response = {
-                "status": "Failed",
-                "message": "Command `%s` not supported." % info_name,
-            }
+            return Misty2pyResponse(
+                False,
+                error_msg="Command `%s` not supported." % info_name,
+                error_type=Misty2pyErrorType.COMMAND,
+            )
 
-        else:
-            endpoint = self.allowed_infos[info_name]
+        endpoint = self.allowed_infos[info_name]
 
-            if len(params) > 0:
-                endpoint += "?"
-                query_string = urlencode(params)
-                endpoint += query_string
+        try:
+            return super().get_info(endpoint, params)
 
-            try:
-                response = super().get_info(endpoint)
-
-            except Exception as e:
-                response = {
-                    "status": "Failed",
-                    "message": "Error occured. Error message: `%s`" % e,
-                }
-
-        return response
+        except Exception as e:
+            return unknown_error(e)
