@@ -1,4 +1,4 @@
-"""EnvLoader class"""
+"""This module contains the EnvLoader class for loading environmental values."""
 from typing import Optional
 
 from dotenv import dotenv_values
@@ -15,5 +15,5 @@ class EnvLoader:
         self.values = dotenv_values(env_path)
 
     def get_ip(self) -> Optional[str]:
-        """Obtains MISTY_IP_ADDRESS from environmental values."""
+        """Obtains `MISTY_IP_ADDRESS` from environmental values."""
         return self.values.get("MISTY_IP_ADDRESS")
