@@ -1,16 +1,16 @@
-"""Generator functions."""
+"""This module contains generator functions."""
 import random
 import string
 
 
 def get_random_string(n: int) -> str:
-    """Constructs an n characters long random string containing ASCII letters and digits.
+    """Constructs an `n` characters long random string containing ASCII letters and digits.
 
     Args:
-        n (int): the required length of the string.
+        n (int): The required length of the string.
 
     Returns:
-        str: the random string.
+        str: The random string.
     """
 
     assert n > 0, "Required string length must be a positive integer."
