@@ -46,7 +46,7 @@ class Status:
             content_type (str): The parameter whose value to return. Accepts `"data"`, `"time"` and `"status"`.
 
         Returns:
-            Any: The value of the requested parameter.
+            Any: The value of the requested parameter or `None` if the parameter does not exist.
         """
         if content_type == "data":
             return self.data
@@ -54,6 +54,7 @@ class Status:
             return self.time
         if content_type == "status":
             return self.status
+        return None
 
     def parse_to_message(self) -> Dict:
         """Returns the current status as a JSON dictionary.
